@@ -18,7 +18,7 @@ class Author:
 @dataclass
 class Dependency:
     name: str
-    op: Literal[">=", "==", "<="]  # two sided possible?
+    op: Literal[">=", "==", "<=", ""]  # two sided possible?
     version: Optional[str]
 
     def __str__(self) -> str:
@@ -85,7 +85,7 @@ requires-python = '$REQUIRES_PYTHON_VERSION'
 # DEP: Define dependencies here. Also see setup.py to support GitHub metadata indexing.
 dependencies = [$DEPENDENCIES]
 # OPTDEP: Define opt-in dependencies here. Also grep over the code base to see other places that might need change.
-#         Example: With 
+#         Example: With
 #               optional-dependencies = { slug = ['python-dotenv>=0.10.4'] }
 #         Users can install $NAME[slug] to also install python-dotenv
 optional-dependencies = { }
@@ -230,8 +230,8 @@ sys.exit(1)
 
 setup(
     name='$NAME',
-    # DEP: pyproject.toml is the authorative source for dependencies. 
-    #      Update the line below to support GitHub metadata indexing. 
+    # DEP: pyproject.toml is the authorative source for dependencies.
+    #      Update the line below to support GitHub metadata indexing.
     install_requires=[$DEPENDENCIES],
 )
 """.strip()
@@ -301,11 +301,11 @@ def license(out: io.TextIOBase, props: LicenseProps) -> None:
 
 template_version_py = Template(
     """
-__all__ = 'VERSION', 'version_info'
+__all__ = "VERSION", "version_info"
 
-VERSION = '$VERSION'
+VERSION = "$VERSION"
 
-# OPTDEP: Add optional dependencies for your users here, e. g. 'devtools', 'typing-extensions'.
+# OPTDEP: Add optional dependencies for your users here, e. g. "devtools", "typing-extensions".
 opt_in_dependencies: list[str] = []
 
 def version_info() -> str:
@@ -317,19 +317,19 @@ def version_info() -> str:
     optional_deps = []
     for p in opt_in_dependencies:
         try:
-            import_module(p.replace('-', '_'))
+            import_module(p.replace("-", "_"))
         except ImportError:
             continue
         optional_deps.append(p)
 
     info = {
-        'pydantic version': VERSION,
-        'install path': Path(__file__).resolve().parent,
-        'python version': sys.version,
-        'platform': platform.platform(),
-        'optional deps. installed': optional_deps,
+        "pydantic version": VERSION,
+        "install path": Path(__file__).resolve().parent,
+        "python version": sys.version,
+        "platform": platform.platform(),
+        "optional deps. installed": optional_deps,
     }
-    return '\\n'.join('{:>30} {}'.format(k + ':', str(v).replace('\\n', ' ')) for k, v in info.items())
+    return "\\n".join("{:>30} {}".format(k + ":", str(v).replace("\\n", " ")) for k, v in info.items())
 """.strip()
 )
 
@@ -351,13 +351,18 @@ template_makefile = Template(
     """
 sources = $NAME tests
 
+# https://hatch.pypa.io/dev/version/#updating
+.PHONY: bump
+bump:
+\thatch version patch
+
 .PHONY: bump-minor
 bump-minor:
-\techo "Not Implemented Yet"
+\thatch version minor
 
 .PHONY: bump-major
 bump-major:
-\techo "Not Implemented Yet"
+\thatch version major
 
 .PHONY: install
 install:
@@ -368,10 +373,11 @@ install:
 .PHONY: refresh-requirements
 refresh-requirements:
 \t@echo "Updating requirements/*.txt files using pip-compile"
-\tfind requirements/ -name '*.txt' ! -name 'all.txt' -type f -delete 
+\tfind requirements/ -name '*.txt' ! -name 'all.txt' -type f -delete
 \tpip-compile -q --resolver backtracking -o requirements/linting.txt requirements/linting.in
 \tpip-compile -q --resolver backtracking -o requirements/testing.txt requirements/testing.in
-\tpip-compile -q --resolver backtracking -o requirements/pyproject.txt pyproject.toml\t
+\tpip-compile -q --resolver backtracking -o requirements/pyproject.txt pyproject.toml
+\tpip-compile -q --resolver backtracking -o requirements/docs.txt requirements/docs.in
 \t# OPTDEP: make sure to also recompile requirements for optional dependencies, e. g. for slug
 \t# pip-compile -q --resolver backtracking -o requirements/pyproject+slug.txt pyproject.toml --extra=slug
 
@@ -399,7 +405,7 @@ test:
 .PHONY: testcov
 testcov: test
 \t@echo "building coverage html"
-\t@coverage html 
+\t@coverage html
 
 .PHONY: all
 all: lint mypy testcov
@@ -421,6 +427,18 @@ clean:
 \trm -f .coverage
 \trm -f .coverage.*
 \trm -rf htmlcov
+
+.PHONY: docs
+docs:
+\tmkdocs serve --dev-addr localhost:8000
+
+.PHONY: build-docs
+build-docs:
+\tmkdocs build --clean --strict
+
+.PHONY: deploy-docs
+deploy-docs:
+\tmkdocs gh-deploy
 """.strip()
 )
 
@@ -563,6 +581,19 @@ def requirements_testing_in(out: io.TextIOBase, props: AnyProps) -> None:
     out.write(raw)
 
 
+template_requirements_docs_in = Template(
+    """
+mkdocs-material
+""".strip()
+)
+
+
+def requirements_docs_in(out: io.TextIOBase, props: AnyProps) -> None:
+    del props  # Unused.
+    raw = template_requirements_docs_in.substitute()
+    out.write(raw)
+
+
 # TODO(liamvdv)
 template_readme_md = Template(
     """
@@ -592,8 +623,10 @@ make refresh-requirements
 make install
 ```
 
+You can run the pre-commit hooks with `pre-commit` or automatically run them before commits with `pre-commit install`. 
+
 ## Dependency Management
-The location of where dependencies are declared depends on their scope. 
+The location of where dependencies are declared depends on their scope.
 
 - Package dependencies must be put into `pyproject.toml [project] .dependencies`.
 - Opt-in dependencies must be put into `pyproject.toml [project] .optional-dependencies`.
@@ -624,6 +657,108 @@ def readme_md(out: io.TextIOBase, props: ReadmeMdProps) -> None:
     out.write(raw)
 
 
+# Input
+# Declare number of needed attributes and check if they are already present in given props.
+# Ask more questions if needed, store the result in plugin specific store (prevent conflicts in plugins)
+
+# Also require additional dependencies in docs.in
+# How it works
+# mkdocs new . # in root directory
+# mkdocs serve
+# mkdocs build [options]
+# mkdocs gh-deploy (will overwrite gh-pages)
+
+# custom domain must go into /docs/CNAME file
+
+template_mkdocs_yml = Template(
+    """
+# For customizations see https://squidfunk.github.io/mkdocs-material/setup/changing-the-colors/
+# inspiration https://github.com/pypa/hatch/blob/master/mkdocs.yml
+site_name: $NAME
+repo_name: $REPO_NAME
+site_description: $DESCRIPTION
+site_url: $SITE_URL
+repo_url: $REPO_URL
+edit_uri: blob/master/docs
+copyright: "Copyright &copy; $AUTHORS $YEARSPAN - present"
+theme:
+  name: material
+  features:
+    - content.code.copy
+    - content.code.annotate
+
+markdown_extensions:
+  - pymdownx.highlight:
+      anchor_linenums: true
+      use_pygments: true
+  - pymdownx.inlinehilite
+  - pymdownx.snippets
+  - pymdownx.superfences
+
+plugins:
+- search
+""".strip()
+)
+
+
+class MkdocsYmlProps(TypedDict):
+    name: str
+    documentation_url: str
+    source_url: str
+    description: str
+    authors: list[Author]
+
+
+def mkdocs_yml(out: io.TextIOBase, props: MkdocsYmlProps) -> None:
+    NAME = props["name"]
+    DESCRIPTION = props["description"]
+    REPO_URL = props["source_url"]
+    REPO_NAME = "/".join(props["source_url"].split("/")[-2:])
+    SITE_URL = props["documentation_url"]
+    AUTHORS = ", ".join([author.name for author in props["authors"]])
+    YEARSPAN = str(date.today().year)
+
+    raw = template_mkdocs_yml.substitute(
+        NAME=NAME,
+        DESCRIPTION=DESCRIPTION,
+        REPO_URL=REPO_URL,
+        SITE_URL=SITE_URL,
+        AUTHORS=AUTHORS,
+        YEARSPAN=YEARSPAN,
+        REPO_NAME=REPO_NAME,
+    )
+
+    out.write(raw)
+
+
+template_docs_index_md = Template(
+    """
+# Welcome to your documentation site!
+
+For full documentation visit [mkdocs.org](https://www.mkdocs.org).
+
+## Commands
+
+* `mkdocs serve` - Start the live-reloading docs server.
+* `mkdocs build` - Build the documentation site.
+
+## Project layout
+
+    mkdocs.yml    # The configuration file.
+    docs/
+        index.md  # The documentation homepage.
+        ...       # Other markdown pages, images and other files.
+
+""".strip()
+)
+
+
+def docs_index_md(out: io.TextIOBase, props: AnyProps) -> None:
+    del props  # Unused.
+    raw = template_docs_index_md.substitute()
+    out.write(raw)
+
+
 class TemplateProps(  # type: ignore[misc]
     PyprojectTomlProps,
     SetupPyProps,
@@ -632,6 +767,7 @@ class TemplateProps(  # type: ignore[misc]
     MakefileProps,
     VersionPyProps,
     ReadmeMdProps,
+    MkdocsYmlProps,
 ):
     pass
 
